@@ -5,7 +5,7 @@ def main():
     add_val = c.calc_add()
     print( "result of addition " + str(add_val))
     mult_val = c.calc_multiply()
-    print( "result of multiplication " + str(mult_val))
+    #print( "result of multiplication " + str(mult_val))
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
